<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>nový</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Každý %1 ťah</numerusform>
            <numerusform>Každé %1 ťahy</numerusform>
            <numerusform>Každých %1 ťahov</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Upraviť zbrane</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Neplatná schéma zbraní</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Upraviť schémy</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 bol(a) odstránený(á) zo zoznamu ignorovaných</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 bol(a) pridaný(á) do zoznamu ignorovaných</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 bol(a) odstránený(á) zo zoznamu priateľov</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 bol(a) pridaný(á) do zoznamu priateľov</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Nie je možné spustiť server</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Nie je možné zapísať záznam do súboru %1</translation>
    </message>
    <message>
        <source>new</source>
        <translation>nový</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Prosím vyberte záznam zo zoznamu vyššie</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>sk.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Nie je možné otvoriť demosúbor %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Témy</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Všetky</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Malá</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Stredná</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Veľká</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Jaskyňa</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Pojašená</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Malé tunely</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Stredné tunely</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Veľké tunely</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Malé plávajúce ostrovčeky</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Stredné plávajúce ostrovčeky</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Veľké plávajúce ostrovčeky</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Stanica nebola nájdená. Prosím, skontrolujte názov stanice a nastavenia portu.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Spojenie odmietnuté</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Dôvod odchodu: </translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Miestnosť zrušená</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Boli ste vykopnutý</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation>Vaša prezývka %1 je
zaregistrovaná na Hedgewars.org
Prosím, zadajte heslo alebo
si vyberte inú prezývku:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 prišiel do miestnosti</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 sa pridal</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 odišiel (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 odišiel</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf vrátil chybu počas renderovania textu, s najväčšou pravdepodobnosťou sa jedná o chybu vo freetype2. Doporučujeme aktualizovať vašu knižnicu freetype.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Správa serveru:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Nastaviť správu</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Vymazať vyrovnávaciu pamäť účtov</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Pripájam sa...</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Ocenenie za najlepší zásah vyhral(a) &lt;b&gt;%1&lt;/b&gt; so ziskom &lt;b&gt;%2&lt;/b&gt; bodov.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;jedným&lt;/b&gt; zabitím počas ťahu.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Najlepším zabijákom je &lt;b&gt;%1&lt;/b&gt; s &lt;b&gt;%2&lt;/b&gt; zabitiami počas ťahu.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Celkovo bol v tomto kole zabitý &lt;b&gt;jeden&lt;/b&gt; ježko.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Celkovo boli v tomto kole zabití &lt;b&gt;%1&lt;/b&gt; ježkovia.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Miestna hra (Hrať hru proti počítaču)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Sieťová hra (Hrať hru proti súperom na sieti)</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Štart</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Prosím vyberte server zo zoznamu vyššie</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Ovládanie</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>LAN hra</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Oficiálny server</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nový team</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Upraviť team</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Vymazať tím</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation>Nová schéma pre zbrane</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation>Upraviť schému pre zbrane</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation>Vymazať schému pre zbrane</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Dialóg na zmenu mena</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Zadajte nový názov súboru:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Nemôžem premenovať na</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Nemôžem vymazať súbor</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Prosím vyberte záznam zo zoznamu</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Vytvoriť</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Pripojiť sa</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Vlastnosti pre admina</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Názov miestnosti:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Táto hra je v lobby.
Môžete sa pridať a začať hru akonáhle hra skončí.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Táto hra práve prebieha.
Môžete sa pridať a sledovať hru, ale ak chcete hrať budete musieť počkať na koniec hry.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 je hostiteľom. Može meniť nastavenia a spúšťať hru.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Náhodná mapa</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Hry môžu byť hrané na predvytvorených alebo náhodných mapách.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Schéma hry určuje všeobecné voľby ako napríklad Dĺžka kola, Režim rýchlej smrti alebo Vampírizmus.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Schémy hry určuje dostupné zbrane a množstvo výzbroje.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>K tejto miestnosti je pripojený jeden klient.</numerusform>
            <numerusform>K tejto miestnosti sú pripojení %1 klienti.</numerusform>
            <numerusform>K tejto miestnosti je pripojených %1 klientov.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>V tejto miestnosti je jeden hrajúci team.</numerusform>
            <numerusform>V tejto miestnosti sú %1 hrajúce teamy.</numerusform>
            <numerusform>V tejto miestnosti je %1 hrajúcich teamov.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Prosím zadajte názov miestnosti</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Prosím vyberte miestnosť zo zoznamu</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Náhodné bludisko</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Enable random mines</source>
        <translation>Povoliť náhodne rozmiestnené míny</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Pridať 80% škody, ktorú spôsobíte k vášmu zdraviu</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Zdieľanie bolesti vašich protivníkov, zdieľanie ich poškodenia</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Vaši ježkovia sa nemôžu pohnúť, otestujte si vaše delostrelecké schopnosti</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Náhodné</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekúnd</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Ubráňte pevnosť a znižte nepriateľov, maximálne dve teamové farby!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Teamy začnú na opačných stranách terénu, maximálne dve teamové farby!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Krajina sa nedá zničiť!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Pridať nezničiteľný okraj okolo terénu</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Nižšia gravitácia</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Pomocné laserové zameriavanie</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Všetci ježkovia majú osobné silové pole</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Poradie hrania je náhodné miesto poradia hráčov v miestnosti.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Hra s Kráľom. Ak zomrie, vaša strana prehráva.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Pred začatím hry sa súperi striedajú v umiestňovaní ježkov.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Výzbroj je zdieľaná medzi všetkými tímami, ktoré majú tú istú farbu.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Zakázať trámy pri generovaní náhodných máp.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Východzie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Jednoduchá hra (rýchla hra proti počítaču, s preddefinovanými nastaveniami)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Multiplayer (hrať hru, pri ktorej sa striedate s hráčmi pri počítači alebo proti počítačovým teamom)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Tréningový režim (vylepšujte si svoje zručnosti v rade tréningových misií). VO VÝVOJI</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demá (prehrávanie natočených demonahrávok)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Načítať (načíta v minulosti uloženú hru)</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Vykopnúť</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Obmedziť pripojenia</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Obmedziť pripojenie k teamu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Zakázať</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Nasledovať</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovať</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Pridať priateľa</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Zrušiť ignorovanie</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Odstrániť priateľa</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Kontrolovať aktualizácie pri štarte</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Povoliť zvuky</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Zobrazovať FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Iný spôsob zobrazovania škody</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Frontend na celú obrazovku</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Povoliť hudbu</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Pripojiť dátum a čas k súboru so záznamom</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation>Znížená kvalita</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Zobrazovať nápovedu pre zbrane</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Povoliť zvuky vo frontende</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Povoliť hudbu vo frontende</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Efekty vo frontende</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>vygenerovaná mapa...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Človek</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Úroveň</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Východzie nastavenie)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>vygenerované bludisko..</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Misia</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Členovia teamu</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Nastavenia kláves</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Pevnosť</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Teamy</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Nastavenia zvuku/grafiky</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbrane</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Sieťová hra</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Hrajúce teamy</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Modifikátory hry</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Základné nastavenia</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Nastavenia tímu</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Rozličné</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Čas pre míny</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Míny</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Tento program je distribuovaný podľa podmienok GNU General Publice License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Vývojári:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafika:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Preklady:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Osobitné poďakovanie:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Výzbroj</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Stanica:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Rozlíšenie</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Limit FPS</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Sieťový nick</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Názov servera:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Port servera:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzia</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Zvuky:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Úvodná hlasitosť zvuku</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Schéma hry</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Modifikátor poškodenia</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Čas na ťah</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Úvodné zdravie</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Časový limit pre rýchlu smrť</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Zhadzovanie krabíc</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Názov schémy:</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% Falošné míny</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Meno</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Hrobček</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Vlajka</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Hlasy</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Jazykové nastavenia</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Vyžaduje reštart hry</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Toto zostavenie SVN je &apos;stále-vo-vývoji&apos; a nemusí byť kompatibilné s inými verziami hry.
Niektoré vlastnosti nemusia fungovať alebo nemusia byť dokončené. Používajte na vlastné riziko!</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Výbušniny</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>beznázvu</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Spojenie so serverom bolo prerušené</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Nepodarilo sa otvoriť dátový adresár:
%1
Skontrolujte si vašu inštaláciu</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbrane</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>Nie je možné upraviť východziu sadu zbraní</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>Nie je možné vymazať východziu sadu zbraní</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Určite chcete vymazať túto sadu zbraní?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Nepodarilo sa vytvoriť adresár %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Prezývka</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Prosím, zadajte vašu prezývku</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation>Choď!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>východzie</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Spustiť server</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Spojiť</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Nastaviť</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Prehrať demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Načítať</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Nastavenie</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Pripravený</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Náhodný tím</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Názov miestnosti</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Majiteľ</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Pravidlá</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Zbrane</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Sada zbraní</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Pravdepodobnosti</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Zbrane v krabiciach</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Oneskorenie</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Nie je možné spustiť server: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Nie je možné spustiť engine: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Režím vampíra</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Delostrelectvo</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Režim pevností</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Rozdeliť teamy</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Nezničiteľná zem</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Pridať okraj</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Nízka gravitácia</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Laserové zameriavanie</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Nesmrteľnosť</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation>Pridať míny</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Náhodné poradie</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Kráľ</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Umiestňovať ježkov</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Klan zdieľa výzbroj</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Vypnúť trámy</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>hore</translation>
    </message>
    <message>
        <source>left</source>
        <translation>vľavo</translation>
    </message>
    <message>
        <source>right</source>
        <translation>vpravo</translation>
    </message>
    <message>
        <source>down</source>
        <translation>dole</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>útok</translation>
    </message>
    <message>
        <source>put</source>
        <translation>položiť</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>prepnúť</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>nájsť ježka</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>okno výzbroje</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>časovač na 1 sek</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>časovač na 2 sek</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>časovač na 3 sek</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>časovač na 4 sek</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>časovač na 5 sek</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pauza</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>stlmiť hlasitosť</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>zvýšiť hlasitosť</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>zmeniť režim</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>snímať</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>štatistiky
ježkov</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>ukončiť</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>čet</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>história četu</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>potvrdenie</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>presné zameriavanie</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>priblíženie</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>oddialenie</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>reštartovať priblíženie</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>dlhý skok</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>vysoký skok</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Základné ovládanie</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Ovládanie zbraní</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Ovládanie kurzora a kamery</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Iné</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Presun ježka a mierenie:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Prekoná priepasti a prekážky skokom:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Vypáli vami zvolenú zbraň alebo zapne nástroj:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Položí zbraň alebo vyberie cieľ v mieste pod kurzorom:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Prepne vášho momentálne vybraného ježka (ak je to možné):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Zodvihne zbraň alebo nástroj:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Nastaví časovač na bombách a iných zbraniach s časovou rozbuškou:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Presunie kameru na aktívneho ježka:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Presunie kurzor alebo kameru bez použitia myši:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Zmeniť stupeň priblíženia kamery:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Umožní vám rozhovor s vašim teamom alebo všetkými účastníkmi hry:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pauza, pokračovanie alebo opustenie hry:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Zmena hlasitosti v hre počas hrania:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Prepne celoobrazovkový režim:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Urobí snímok obrazovky:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Prepnúť nápisy nad ježkami:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Os</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Hore)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Dole)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Klobúk</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Vľavo)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Vpravo)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Tlačidlo</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Klávesnica</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Myš: Ľavé tlačidlo</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Myš: Prostredné tlačidlo</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Myš: Pravé tlačidlo</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Myš: Kolečko smerom nahor</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Myš: Kolečko smerom nadol</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulátor</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Clear</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Medzera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Rovná sa</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Hore</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Dole</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Pravý shift</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Ľavý shift</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Pravý ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Ľavý ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Pravý alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Ľavý alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Pravý meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Ľavý meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>Tlačidlo A</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>Tlačidlo B</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>Tlačidlo X</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Tlačidlo Y</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>Tlačidlo LB</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>Tlačidlo RB</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Tlačidlo Back</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Tlačidlo Start</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Joystick doľava</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Joystick doprava</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Ľavý prepínač</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Pravý prepínač</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
